@@ -2,18 +2,18 @@ import os
 import sys
 
 import click
+
 from great_expectations import DataContext
 from great_expectations import exceptions as ge_exceptions
 from great_expectations.cli import toolkit
-from great_expectations.cli.datasource import add_datasource as add_datasource_impl
-from great_expectations.cli.docs import build_docs
-from great_expectations.cli.init_messages import (
+from great_expectations.cli.cli_messages import (
     BUILD_DOCS_PROMPT,
     GREETING,
     LETS_BEGIN_PROMPT,
     ONBOARDING_COMPLETE,
     PROJECT_IS_COMPLETE,
     RUN_INIT_AGAIN,
+    SECTION_SEPARATOR,
     SETUP_SUCCESS,
     SLACK_LATER,
     SLACK_SETUP_COMPLETE,
@@ -21,6 +21,8 @@ from great_expectations.cli.init_messages import (
     SLACK_SETUP_PROMPT,
     SLACK_WEBHOOK_PROMPT,
 )
+from great_expectations.cli.datasource import add_datasource as add_datasource_impl
+from great_expectations.cli.docs import build_docs
 from great_expectations.cli.util import cli_message, is_sane_slack_webhook
 from great_expectations.core.usage_statistics.usage_statistics import send_usage_message
 from great_expectations.exceptions import (
@@ -116,8 +118,14 @@ def init(target_directory, view, usage_stats):
         else:
             datasources = context.list_datasources()
             if len(datasources) == 0:
+                cli_message(SECTION_SEPARATOR)
+                if not click.confirm(
+                    "Would you like to configure a Datasource?", default=True
+                ):
+                    cli_message("Okay, bye!")
+                    sys.exit(1)
                 datasource_name, data_source_type = add_datasource_impl(
-                    context, choose_one_data_asset=True
+                    context, choose_one_data_asset=False
                 )
                 if not datasource_name:  # no datasource was created
                     sys.exit(1)
@@ -126,19 +134,52 @@ def init(target_directory, view, usage_stats):
             if len(datasources) == 1:
                 datasource_name = datasources[0]["name"]
 
-                success, suite_name = toolkit.create_expectation_suite(
+                cli_message(SECTION_SEPARATOR)
+                if not click.confirm(
+                    "Would you like to profile new Expectations for a single data asset within your new Datasource?",
+                    default=True,
+                ):
+                    cli_message(
+                        "Okay, exiting now. To learn more about Profilers, run great_expectations profile --help or visit docs.greatexpectations.io!"
+                    )
+                    sys.exit(1)
+
+                (
+                    success,
+                    suite_name,
+                    profiling_results,
+                ) = toolkit.create_expectation_suite(
                     context,
                     datasource_name=datasource_name,
                     additional_batch_kwargs={"limit": 1000},
-                    open_docs=view,
+                    flag_build_docs=False,
+                    open_docs=False,
                 )
-                if success:
-                    cli_message(
-                        "A new Expectation suite '{}' was added to your project".format(
-                            suite_name
-                        )
-                    )
 
+                cli_message(SECTION_SEPARATOR)
+                if not click.confirm(
+                    "Would you like to build Data Docs?", default=True
+                ):
+                    cli_message(
+                        "Okay, exiting now. To learn more about Data Docs, run great_expectations docs --help or visit docs.greatexpectations.io!"
+                    )
+                    sys.exit(1)
+
+                build_docs(context, view=False)
+
+                if not click.confirm(
+                    "\nWould you like to view your new Expectations in Data Docs? This will open a new browser window.",
+                    default=True,
+                ):
+                    cli_message(
+                        "Okay, exiting now. You can view the site that has been created in a browser, or visit docs.greatexpectations.io for more information!"
+                    )
+                    sys.exit(1)
+                toolkit.attempt_to_open_validation_results_in_data_docs(
+                    context, profiling_results
+                )
+
+                cli_message(SECTION_SEPARATOR)
                 cli_message(SETUP_SUCCESS)
                 sys.exit(0)
     except (
