@@ -66,7 +66,7 @@ We'd love it if you **reach out to us on** the [**Great Expectations Slack Chann
             batch_kwargs = dict()
         self.add_code_cell(
             """\
-from datetime import datetime
+import datetime
 import great_expectations as ge
 import great_expectations.jupyter_ux
 from great_expectations.data_context.types.resource_identifiers import ValidationResultIdentifier
@@ -103,16 +103,21 @@ Let's now rebuild your Data Docs, which helps you communicate about your data wi
             """\
 batch.save_expectation_suite(discard_failed_expectations=False)
 
-# Let's make a simple sortable timestamp. Note this could come from your pipeline runner.
-run_id = datetime.utcnow().strftime("%Y%m%dT%H%M%S.%fZ")
+\"""
+Let's create a run_id. The run_id must be of type RunIdentifier, with optional run_name and run_time instantiation
+arguments (or a dictionary with these keys). The run_name can be any string (this could come from your pipeline
+runner, e.g. Airflow run id). The run_time can be either a dateutil parsable string or a datetime object.
+Note - any provided datetime will be assumed to be a UTC time. If no instantiation arguments are given, run_name will
+be None and run_time will default to the current UTC datetime.
+\"""
+
+run_id = {
+  "run_name": "some_string_that_uniquely_identifies_this_run",  # insert your own run_name here
+  "run_time": datetime.datetime.now(datetime.timezone.utc)
+}
 
 results = context.run_validation_operator("action_list_operator", assets_to_validate=[batch], run_id=run_id)
-expectation_suite_identifier = list(results["details"].keys())[0]
-validation_result_identifier = ValidationResultIdentifier(
-    expectation_suite_identifier=expectation_suite_identifier,
-    batch_identifier=batch.batch_kwargs.to_id(),
-    run_id=run_id
-)
+validation_result_identifier = results.list_validation_result_identifiers()[0]
 context.build_data_docs()
 context.open_data_docs(validation_result_identifier)"""
         )
@@ -237,7 +242,9 @@ Add expectations by calling specific expectation methods on the `batch` object.
 You can see all the available expectations in the **[expectation glossary](https://docs.greatexpectations.io/en/latest/expectation_glossary.html?utm_source=notebook&utm_medium=create_expectations)**."""
         )
 
-    def get_batch_kwargs(self, suite: ExpectationSuite, batch_kwargs: Union[dict, BatchKwargs]):
+    def get_batch_kwargs(
+        self, suite: ExpectationSuite, batch_kwargs: Union[dict, BatchKwargs]
+    ):
         if isinstance(batch_kwargs, dict):
             return self._fix_path_in_batch_kwargs(batch_kwargs)
 
